.. _Download:

Download
========

.. _Conditions of use:

Conditions of use
-----------------

PETGEM is developed as open-source under
:download:`BSD-3 <_downloads/BSD-3.pdf>` license.


.. _Download petgem:

Downloads
---------

Scripts
*******

* PETGEM is available for download at the project website generously hosted by PyPi and GitHub. Download `here <https://pypi.python.org/pypi/petgem/>`__ or `here <https://github.com/ocastilloreyes/petgem>`__.

* ``kernel.py``: python script that manages the PETGEM work-flow. Download :download:`here <_downloads/kernel.py>`.

* ``petsc.opts``: options file for `PETSc <http://www.mcs.anl.gov/petsc/>`__ solvers/preconditioners. Download :download:`here <_downloads/petsc.opts>`.

* ``params.yaml``: file that defines physical parameters of the 3D CSEM survey. Download :download:`here <_downloads/params.yaml>`.

Examples
********

* Example 1: Dataset for the Canonical model of an off-shore hydrocarbon reservoir (Nédélec elements of first-order). Download :download:`here <_downloads/case1.zip>`.

* Example 2: Dataset for the Canonical model of an off-shore hydrocarbon reservoir (Nédélec elements of second-order). Download :download:`here <_downloads/case2.zip>`.

* Example 3: Dataset for the use of PETSc solvers. Download :download:`here <_downloads/case3.zip>`.
